@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import IO, Any, Dict, List, Type, Union, overload
+from typing import IO, Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
@@ -70,7 +70,7 @@ __all__ = ("ACMPCAClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -100,7 +100,7 @@ class Exceptions:
 
 class ACMPCAClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html)
     """
 
@@ -116,7 +116,7 @@ class ACMPCAClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#can_paginate)
         """
 
@@ -125,15 +125,15 @@ class ACMPCAClient(BaseClient):
         *,
         CertificateAuthorityConfiguration: "CertificateAuthorityConfigurationTypeDef",
         CertificateAuthorityType: CertificateAuthorityTypeType,
-        RevocationConfiguration: "RevocationConfigurationTypeDef" = None,
-        IdempotencyToken: str = None,
-        KeyStorageSecurityStandard: KeyStorageSecurityStandardType = None,
-        Tags: List["TagTypeDef"] = None
+        RevocationConfiguration: "RevocationConfigurationTypeDef" = ...,
+        IdempotencyToken: str = ...,
+        KeyStorageSecurityStandard: KeyStorageSecurityStandardType = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateCertificateAuthorityResponseTypeDef:
         """
         Creates a root or subordinate private certificate authority (CA).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.create_certificate_authority)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.create_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#create_certificate_authority)
         """
 
@@ -147,7 +147,7 @@ class ACMPCAClient(BaseClient):
         """
         Creates an audit report that lists every time that your CA private key is used.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.create_certificate_authority_audit_report)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.create_certificate_authority_audit_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#create_certificate_authority_audit_report)
         """
 
@@ -156,35 +156,35 @@ class ACMPCAClient(BaseClient):
         *,
         CertificateAuthorityArn: str,
         Principal: str,
-        Actions: List[ActionTypeType],
-        SourceAccount: str = None
+        Actions: Sequence[ActionTypeType],
+        SourceAccount: str = ...
     ) -> None:
         """
         Grants one or more permissions on a private CA to the AWS Certificate Manager
         (ACM) service principal (`acm.amazonaws.com` ).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.create_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.create_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#create_permission)
         """
 
     def delete_certificate_authority(
-        self, *, CertificateAuthorityArn: str, PermanentDeletionTimeInDays: int = None
+        self, *, CertificateAuthorityArn: str, PermanentDeletionTimeInDays: int = ...
     ) -> None:
         """
         Deletes a private certificate authority (CA).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.delete_certificate_authority)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.delete_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#delete_certificate_authority)
         """
 
     def delete_permission(
-        self, *, CertificateAuthorityArn: str, Principal: str, SourceAccount: str = None
+        self, *, CertificateAuthorityArn: str, Principal: str, SourceAccount: str = ...
     ) -> None:
         """
         Revokes permissions on a private CA granted to the AWS Certificate Manager (ACM)
         service principal (acm.amazonaws.com).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.delete_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.delete_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#delete_permission)
         """
 
@@ -192,7 +192,7 @@ class ACMPCAClient(BaseClient):
         """
         Deletes the resource-based policy attached to a private CA.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.delete_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.delete_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#delete_policy)
         """
 
@@ -203,7 +203,7 @@ class ACMPCAClient(BaseClient):
         Lists information about your private certificate authority (CA) or one that has
         been shared with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.describe_certificate_authority)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.describe_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#describe_certificate_authority)
         """
 
@@ -216,21 +216,21 @@ class ACMPCAClient(BaseClient):
         pca/latest/APIReference/API_CreateCertificateAuthorityAuditReport.html>`__
         action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.describe_certificate_authority_audit_report)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.describe_certificate_authority_audit_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#describe_certificate_authority_audit_report)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#generate_presigned_url)
         """
 
@@ -241,7 +241,7 @@ class ACMPCAClient(BaseClient):
         Retrieves a certificate from your private CA or one that has been shared with
         you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.get_certificate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.get_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#get_certificate)
         """
 
@@ -252,7 +252,7 @@ class ACMPCAClient(BaseClient):
         Retrieves the certificate and certificate chain for your private certificate
         authority (CA) or one that has been shared with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.get_certificate_authority_certificate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.get_certificate_authority_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#get_certificate_authority_certificate)
         """
 
@@ -263,7 +263,7 @@ class ACMPCAClient(BaseClient):
         Retrieves the certificate signing request (CSR) for your private certificate
         authority (CA).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.get_certificate_authority_csr)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.get_certificate_authority_csr)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#get_certificate_authority_csr)
         """
 
@@ -271,7 +271,7 @@ class ACMPCAClient(BaseClient):
         """
         Retrieves the resource-based policy attached to a private CA.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.get_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.get_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#get_policy)
         """
 
@@ -280,12 +280,12 @@ class ACMPCAClient(BaseClient):
         *,
         CertificateAuthorityArn: str,
         Certificate: Union[bytes, IO[bytes], StreamingBody],
-        CertificateChain: Union[bytes, IO[bytes], StreamingBody] = None
+        CertificateChain: Union[bytes, IO[bytes], StreamingBody] = ...
     ) -> None:
         """
         Imports a signed private CA certificate into ACM Private CA.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.import_certificate_authority_certificate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.import_certificate_authority_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#import_certificate_authority_certificate)
         """
 
@@ -296,54 +296,50 @@ class ACMPCAClient(BaseClient):
         Csr: Union[bytes, IO[bytes], StreamingBody],
         SigningAlgorithm: SigningAlgorithmType,
         Validity: "ValidityTypeDef",
-        ApiPassthrough: "ApiPassthroughTypeDef" = None,
-        TemplateArn: str = None,
-        ValidityNotBefore: "ValidityTypeDef" = None,
-        IdempotencyToken: str = None
+        ApiPassthrough: "ApiPassthroughTypeDef" = ...,
+        TemplateArn: str = ...,
+        ValidityNotBefore: "ValidityTypeDef" = ...,
+        IdempotencyToken: str = ...
     ) -> IssueCertificateResponseTypeDef:
         """
         Uses your private certificate authority (CA), or one that has been shared with
         you, to issue a client certificate.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.issue_certificate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.issue_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#issue_certificate)
         """
 
     def list_certificate_authorities(
-        self,
-        *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        ResourceOwner: ResourceOwnerType = None
+        self, *, NextToken: str = ..., MaxResults: int = ..., ResourceOwner: ResourceOwnerType = ...
     ) -> ListCertificateAuthoritiesResponseTypeDef:
         """
         Lists the private certificate authorities that you created by using the
         `CreateCertificateAuthority <https://docs.aws.amazon.com/acm-
         pca/latest/APIReference/API_CreateCertificateAuthority.html>`__ action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.list_certificate_authorities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.list_certificate_authorities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#list_certificate_authorities)
         """
 
     def list_permissions(
-        self, *, CertificateAuthorityArn: str, NextToken: str = None, MaxResults: int = None
+        self, *, CertificateAuthorityArn: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListPermissionsResponseTypeDef:
         """
         List all permissions on a private CA, if any, granted to the AWS Certificate
         Manager (ACM) service principal (acm.amazonaws.com).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.list_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.list_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#list_permissions)
         """
 
     def list_tags(
-        self, *, CertificateAuthorityArn: str, NextToken: str = None, MaxResults: int = None
+        self, *, CertificateAuthorityArn: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListTagsResponseTypeDef:
         """
         Lists the tags, if any, that are associated with your private CA or one that has
         been shared with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#list_tags)
         """
 
@@ -351,7 +347,7 @@ class ACMPCAClient(BaseClient):
         """
         Attaches a resource-based policy to a private CA.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.put_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.put_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#put_policy)
         """
 
@@ -359,7 +355,7 @@ class ACMPCAClient(BaseClient):
         """
         Restores a certificate authority (CA) that is in the `DELETED` state.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.restore_certificate_authority)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.restore_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#restore_certificate_authority)
         """
 
@@ -373,27 +369,27 @@ class ACMPCAClient(BaseClient):
         """
         Revokes a certificate that was issued inside ACM Private CA.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.revoke_certificate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.revoke_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#revoke_certificate)
         """
 
     def tag_certificate_authority(
-        self, *, CertificateAuthorityArn: str, Tags: List["TagTypeDef"]
+        self, *, CertificateAuthorityArn: str, Tags: Sequence["TagTypeDef"]
     ) -> None:
         """
         Adds one or more tags to your private CA.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.tag_certificate_authority)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.tag_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#tag_certificate_authority)
         """
 
     def untag_certificate_authority(
-        self, *, CertificateAuthorityArn: str, Tags: List["TagTypeDef"]
+        self, *, CertificateAuthorityArn: str, Tags: Sequence["TagTypeDef"]
     ) -> None:
         """
         Remove one or more tags from your private CA.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.untag_certificate_authority)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.untag_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#untag_certificate_authority)
         """
 
@@ -401,13 +397,13 @@ class ACMPCAClient(BaseClient):
         self,
         *,
         CertificateAuthorityArn: str,
-        RevocationConfiguration: "RevocationConfigurationTypeDef" = None,
-        Status: CertificateAuthorityStatusType = None
+        RevocationConfiguration: "RevocationConfigurationTypeDef" = ...,
+        Status: CertificateAuthorityStatusType = ...
     ) -> None:
         """
         Updates the status or configuration of a private certificate authority (CA).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Client.update_certificate_authority)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Client.update_certificate_authority)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/client.html#update_certificate_authority)
         """
 
@@ -416,7 +412,7 @@ class ACMPCAClient(BaseClient):
         self, operation_name: Literal["list_certificate_authorities"]
     ) -> ListCertificateAuthoritiesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Paginator.ListCertificateAuthorities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Paginator.ListCertificateAuthorities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/paginators.html#listcertificateauthoritiespaginator)
         """
 
@@ -425,21 +421,21 @@ class ACMPCAClient(BaseClient):
         self, operation_name: Literal["list_permissions"]
     ) -> ListPermissionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Paginator.ListPermissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Paginator.ListPermissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/paginators.html#listpermissionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tags"]) -> ListTagsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Paginator.ListTags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Paginator.ListTags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/paginators.html#listtagspaginator)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["audit_report_created"]) -> AuditReportCreatedWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#auditreportcreatedwaiter)
         """
 
@@ -448,13 +444,13 @@ class ACMPCAClient(BaseClient):
         self, waiter_name: Literal["certificate_authority_csr_created"]
     ) -> CertificateAuthorityCSRCreatedWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#certificateauthoritycsrcreatedwaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["certificate_issued"]) -> CertificateIssuedWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#certificateissuedwaiter)
         """
