@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -88,6 +88,7 @@ __all__ = (
     "ListPermissionsResponseTypeDef",
     "ListTagsRequestRequestTypeDef",
     "ListTagsResponseTypeDef",
+    "OcspConfigurationTypeDef",
     "OtherNameTypeDef",
     "PaginatorConfigTypeDef",
     "PermissionTypeDef",
@@ -230,7 +231,7 @@ _OptionalCreateCertificateAuthorityRequestRequestTypeDef = TypedDict(
         "RevocationConfiguration": "RevocationConfigurationTypeDef",
         "IdempotencyToken": str,
         "KeyStorageSecurityStandard": KeyStorageSecurityStandardType,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -256,7 +257,7 @@ _RequiredCreatePermissionRequestRequestTypeDef = TypedDict(
     {
         "CertificateAuthorityArn": str,
         "Principal": str,
-        "Actions": List[ActionTypeType],
+        "Actions": Sequence[ActionTypeType],
     },
 )
 _OptionalCreatePermissionRequestRequestTypeDef = TypedDict(
@@ -300,7 +301,7 @@ CsrExtensionsTypeDef = TypedDict(
     "CsrExtensionsTypeDef",
     {
         "KeyUsage": "KeyUsageTypeDef",
-        "SubjectInformationAccess": List["AccessDescriptionTypeDef"],
+        "SubjectInformationAccess": Sequence["AccessDescriptionTypeDef"],
     },
     total=False,
 )
@@ -421,10 +422,10 @@ ExtendedKeyUsageTypeDef = TypedDict(
 ExtensionsTypeDef = TypedDict(
     "ExtensionsTypeDef",
     {
-        "CertificatePolicies": List["PolicyInformationTypeDef"],
-        "ExtendedKeyUsage": List["ExtendedKeyUsageTypeDef"],
+        "CertificatePolicies": Sequence["PolicyInformationTypeDef"],
+        "ExtendedKeyUsage": Sequence["ExtendedKeyUsageTypeDef"],
         "KeyUsage": "KeyUsageTypeDef",
-        "SubjectAlternativeNames": List["GeneralNameTypeDef"],
+        "SubjectAlternativeNames": Sequence["GeneralNameTypeDef"],
     },
     total=False,
 )
@@ -662,6 +663,27 @@ ListTagsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredOcspConfigurationTypeDef = TypedDict(
+    "_RequiredOcspConfigurationTypeDef",
+    {
+        "Enabled": bool,
+    },
+)
+_OptionalOcspConfigurationTypeDef = TypedDict(
+    "_OptionalOcspConfigurationTypeDef",
+    {
+        "OcspCustomCname": str,
+    },
+    total=False,
+)
+
+
+class OcspConfigurationTypeDef(
+    _RequiredOcspConfigurationTypeDef, _OptionalOcspConfigurationTypeDef
+):
+    pass
+
+
 OtherNameTypeDef = TypedDict(
     "OtherNameTypeDef",
     {
@@ -702,7 +724,7 @@ _RequiredPolicyInformationTypeDef = TypedDict(
 _OptionalPolicyInformationTypeDef = TypedDict(
     "_OptionalPolicyInformationTypeDef",
     {
-        "PolicyQualifiers": List["PolicyQualifierInfoTypeDef"],
+        "PolicyQualifiers": Sequence["PolicyQualifierInfoTypeDef"],
     },
     total=False,
 )
@@ -759,6 +781,7 @@ RevocationConfigurationTypeDef = TypedDict(
     "RevocationConfigurationTypeDef",
     {
         "CrlConfiguration": "CrlConfigurationTypeDef",
+        "OcspConfiguration": "OcspConfigurationTypeDef",
     },
     total=False,
 )
@@ -776,7 +799,7 @@ TagCertificateAuthorityRequestRequestTypeDef = TypedDict(
     "TagCertificateAuthorityRequestRequestTypeDef",
     {
         "CertificateAuthorityArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -803,7 +826,7 @@ UntagCertificateAuthorityRequestRequestTypeDef = TypedDict(
     "UntagCertificateAuthorityRequestRequestTypeDef",
     {
         "CertificateAuthorityArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
