@@ -35,7 +35,7 @@ __all__ = (
 
 class AuditReportCreatedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#auditreportcreatedwaiter)
     """
 
@@ -44,32 +44,32 @@ class AuditReportCreatedWaiter(Boto3Waiter):
         *,
         CertificateAuthorityArn: str,
         AuditReportId: str,
-        WaiterConfig: WaiterConfigTypeDef = None
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#auditreportcreatedwaiter)
         """
 
 
 class CertificateAuthorityCSRCreatedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#certificateauthoritycsrcreatedwaiter)
     """
 
     def wait(
-        self, *, CertificateAuthorityArn: str, WaiterConfig: WaiterConfigTypeDef = None
+        self, *, CertificateAuthorityArn: str, WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#certificateauthoritycsrcreatedwaiter)
         """
 
 
 class CertificateIssuedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#certificateissuedwaiter)
     """
 
@@ -78,9 +78,9 @@ class CertificateIssuedWaiter(Boto3Waiter):
         *,
         CertificateAuthorityArn: str,
         CertificateArn: str,
-        WaiterConfig: WaiterConfigTypeDef = None
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_acm_pca/waiters.html#certificateissuedwaiter)
         """
